@@ -14,7 +14,7 @@
 # along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 
-from stylo_metrix.functions import analyze_dir, analyze_text, save_csv, save_npy
+from stylo_metrix.functions import analyze_dir, analyze_text, save_csv, save_npy, remove_empty_columns
 from stylo_metrix.pipeline.stylo_metrix_pipe import StyloMetrixPipe
 from stylo_metrix.structures import CustomMetric, Metric, MetricsGroup
 from stylo_metrix.utils import incidence, ratio, mean, median, stdev
\ No newline at end of file
