@@ -15,5 +15,8 @@
 
 
 from stylo_metrix.metrics.en.grammatical_forms import grammatical_forms_group
-
-original_group = grammatical_forms_group
+from stylo_metrix.metrics.en.syntactic_en import syntactic_group
+from stylo_metrix.metrics.en.lexical_en import lexical_group
+original_group = grammatical_forms_group \
+                 + syntactic_group \
+                 + lexical_group
