@@ -518,6 +518,30 @@ class G_ADJ_SUP(GrammaticalForms):
         return result
 
 
+class G_ADV_POS(GrammaticalForms):
+    name_en = "Adverbs Positive Degree"
+
+    def count(self, doc):
+        result = self.incidence(doc, attr_name='adverbs', attr_value="positive_adverb", pos_range='all')
+        return result
+
+
+class G_ADV_COMP(GrammaticalForms):
+    name_en = "Adverbs Comparative Degree"
+
+    def count(self, doc):
+        result = self.incidence(doc, attr_name='adverbs', attr_value="comparative_adverb", pos_range='all')
+        return result
+
+
+class G_ADV_SUP(GrammaticalForms):
+    name_en = "Adverbs Comparative Degree"
+
+    def count(self, doc):
+        result = self.incidence(doc, attr_name='adverbs', attr_value="superlative_adverb", pos_range='all')
+        return result
+
+
 GRAMMATICAL_FORMS = [
     G_V,
     G_PR_S,
@@ -579,6 +603,10 @@ GRAMMATICAL_FORMS = [
     G_ADJ_POS,
     G_ADJ_COMP,
     G_ADJ_SUP,
+    G_ADV_POS,
+    G_ADV_COMP,
+    G_ADV_SUP,
+
 ]
 
 grammatical_forms_group = MetricsGroup([m() for m in GRAMMATICAL_FORMS])
