@@ -16,7 +16,6 @@
 
 from stylo_metrix.pipeline.en.dictionary_en import TAGS_DICT, WORDS_POS, FUNCTION_WORDS
 
-
 """ METRICS FOR THE PRESENT TENSES [PASSIVE & ACTIVE VOICE]"""
 
 
@@ -52,6 +51,7 @@ def present_simple(doc):
             head = token.head
             present_simple[head] = "present_simple"
             present_simple[token] = "present_simple"
+
             for t in head.subtree:
                 if t.tag_ == "VB" and t.dep_ == "conj":
                     present_simple[t] = "present_simple"
@@ -167,8 +167,8 @@ def present_cont_pas(doc):
                     present_cont_pas[t] = "present_cont_passive"
                     present_cont_pas[token] = "present_cont_passive"
 
-                if t.tag_ == "VBN" and t.dep_ == "conj":
-                    present_cont_pas[t] = "present_cont_passive"
+                    if t.tag_ == "VBN" and t.dep_ == "conj":
+                        present_cont_pas[t] = "present_cont_passive"
     return present_cont_pas
 
 
@@ -217,48 +217,43 @@ def present_perfect(doc):
 
         if token.lemma_ == "have" and (token.tag_ == "VBZ" or token.tag_ == "VBP") and token.head.tag_ == "VBN":
             head = token.head
+            verbs.append(head)
+            verbs.append(token)
 
-            if head not in verbs:
-                verbs.append(head)
-                verbs.append(token)
-
-            for key in verbs_perfect_passive:
+            for key in verbs_perfect_passive.keys():
                 for verb in verbs:
                     if key == verb:
                         verbs.remove(head)
                         verbs.remove(token)
 
-            for tok in head.children:
-                if tok.tag_ == "VBN" and tok.dep_ == "conj" and head in verbs and tok not in verbs:
-                    verbs.append(tok)
+            for tok in head.subtree:
+                if head in verbs:
+                    if tok.tag_ == "VBN" and tok.dep_ == "conj":
+                        verbs.append(tok)
 
         if (token.tag_ == "VBZ" or token.tag_ == "VBP") and token.head.tag_ == "VBN":
             head = token.head
+            verbs.append(head)
 
-            if head not in verbs:
-                verbs.append(head)
-
-            for key in verbs_perfect_passive:
+            for key in verbs_perfect_passive.keys():
                 for verb in verbs:
-                    if key == verb:
+                    if head in verbs and key == verb:
                         verbs.remove(head)
 
-            for key in verbs_ind_pas:
+            for key in verbs_ind_pas.keys():
                 for verb in verbs:
-                    if key == verb:
+                    if head in verbs and key == verb:
                         verbs.remove(head)
 
-            for key in verbs_cont_pas:
+            for key in verbs_cont_pas.keys():
                 for verb in verbs:
-                    if key == verb:
+                    if head in verbs and key == verb:
                         verbs.remove(head)
 
             for tok in head.subtree:
-                if tok.tag_ == "VBN" and tok.dep_ == "conj" and head in verbs and tok not in verbs:
-                    verbs.append(tok)
-
-            if head in verbs:
-                aux[token] = "present_perfect"
+                if head in verbs:
+                    if tok.tag_ == "VBN" and tok.dep_ == "conj" and head in verbs and tok not in verbs:
+                        verbs.append(tok)
 
     present_perfect = {}
 
@@ -509,14 +504,16 @@ def future_simple_passive(doc):
 
 def future_cont(doc):
     future_progr = {}
+
     for token in doc:
         if (str(token)[len(str(token)) - 2:] == "ll" or token.lemma_ == "will") \
                 and token.head.tag_ == "VBG" and token.head not in future_progr:
+
             head = token.head
             future_progr[head] = "future_progr"
 
             for t in head.subtree:
-                if t.lemma_ == "have":
+                if t.lemma_ == "have" and head in future_progr:
                     del future_progr[head]
 
                 if t.tag_ == "VBG" and t.dep_ == "conj":
@@ -838,10 +835,10 @@ def should_perf_active(doc):
                     should_perf_active[head] = "should_perf_active"
                     should_perf_active[t] = "should_perf_active"
 
-            for j in head.children:
-                if j.lemma_ == "be" and head in should_perf_active:
-                    del should_perf_active[head]
-                    del should_perf_active[t]
+                    for k in head.children:
+                        if k.text == "been" and k.dep_ != "ROOT" and (head in should_perf_active):
+                            del should_perf_active[head]
+                            del should_perf_active[t]
 
             if head in should_perf_active.keys():
                 should_perf_active[token] = "should_perf_active"
@@ -865,8 +862,6 @@ def should_perf_passive(doc):
                     should_perf_passive[head] = "should_perf_passive"
                     should_perf_passive[t] = "should_perf_passive"
                     should_perf_passive[token] = "should_perf_passive"
-                if t.lemma_ == "have":
-                    should_perf_passive[t] = "should_perf_passive"
 
             for j in head.subtree:
                 if (j.tag_ == "VBN" or j.tag_ == "VBD") and j.dep_ == "conj" and head in should_perf_passive:
@@ -942,10 +937,10 @@ def must_perf_active(doc):
                     must_perf_active[head] = "must_perf_active"
                     must_perf_active[t] = "must_perf_active"
 
-            for tkn in head.children:
-                if tkn.lemma_ == "be" and head in must_perf_active:
-                    del must_perf_active[head]
-                    del must_perf_active[t]
+                    for tkn in head.children:
+                        if tkn.text == "been" and tkn.dep_ != "ROOT":
+                            del must_perf_active[head]
+                            del must_perf_active[t]
 
             if head in must_perf_active.keys():
                 must_perf_active[token] = "must_perf_active"
@@ -969,8 +964,10 @@ def must_perf_passive(doc):
                     must_perf_passive[head] = "could_perf_passive"
                     must_perf_passive[token] = "could_perf_passive"
                     must_perf_passive[tkn] = "could_perf_passive"
-                if tkn.lemma_ == "have":
-                    must_perf_passive[tkn] = "could_perf_passive"
+
+                    for tkn in head.children:
+                        if tkn.lemma_ == "have":
+                            must_perf_passive[tkn] = "could_perf_passive"
 
             for j in head.subtree:
                 if (j.tag_ == "VBN" or j.tag_ == "VBD") and j.dep_ == "conj" and head in must_perf_passive:
@@ -1102,10 +1099,10 @@ def could_perf_active(doc):
                     could_perf_active[head] = "could_perf"
                     could_perf_active[t] = "could_perf"
 
-            for j in head.children:
-                if j.lemma_ == "be" and head in could_perf_active:
-                    del could_perf_active[head]
-                    del could_perf_active[t]
+                    for j in head.subtree:
+                        if j.text == "been" and j.dep_ != "ROOT" and (head in could_perf_active):
+                            del could_perf_active[head]
+                            del could_perf_active[t]
 
             if head in could_perf_active.keys():
                 could_perf_active[token] = "could_perf"
@@ -1129,8 +1126,10 @@ def could_perf_passive(doc):
                     could_perf_passive[head] = "could_perf_passive"
                     could_perf_passive[t] = "could_perf_passive"
                     could_perf_passive[token] = "could_perf_passive"
-                if t.lemma_ == "have":
-                    could_perf_passive[t] = "could_perf_passive"
+
+                    for k in head.children:
+                        if k.lemma_ == "have":
+                            could_perf_passive[k] = "could_perf_passive"
 
             for k in head.subtree:
                 if k.tag_ == "VBN" and k.dep_ == "conj" and head in could_perf_passive:
@@ -1232,7 +1231,6 @@ def might_perf_active(doc):
     might_perf_active = {}
 
     for token in doc:
-
         if token.lemma_ == "might" and token.head.tag_ == "VBN":
             head = token.head
 
@@ -1241,10 +1239,10 @@ def might_perf_active(doc):
                     might_perf_active[head] = "might_perf"
                     might_perf_active[t] = "might_perf"
 
-            for tkn in head.children:
-                if tkn.lemma_ == "be" and head in might_perf_active:
-                    del might_perf_active[head]
-                    del might_perf_active[t]
+                    for k in head.children:
+                        if k.text == "been" and k.dep_ != "ROOT" and (head in might_perf_active):
+                            del might_perf_active[head]
+                            del might_perf_active[t]
 
             if head in might_perf_active.keys():
                 might_perf_active[token] = "might_perf"
@@ -1268,8 +1266,10 @@ def might_perf_passive(doc):
                     might_perf_passive[head] = "might_perf_passive"
                     might_perf_passive[token] = "might_perf_passive"
                     might_perf_passive[t] = "might_perf_passive"
-                if t.lemma_ == "have":
-                    might_perf_passive[t] = "might_perf_passive"
+
+                    for k in head.children:
+                        if k.lemma_ == "have":
+                            might_perf_passive[k] = "might_perf_passive"
 
             for k in head.subtree:
                 if k.tag_ == "VBN" and k.dep_ == "conj" and head in might_perf_passive:
@@ -1323,18 +1323,78 @@ def adjectives(doc):
                     adj[head] = "superlative_adjective"
                     adj[child] = "superlative_adjective"
 
-        if "Degree=Sup" in token.morph and token.pos_ != "ADV":
+        if "Degree=Sup" in token.morph and token.tag_ == "JJS" and token.head.pos_ != "ADV":
             adj[token] = "superlative_adjective"
 
         if "Degree=Pos" in token.morph and token.pos_ == "ADJ":
             head = token
-            for child in token.subtree:
+            for child in head.children:
                 if "PunctType=Dash" in child.morph:
-                    for t in token.children:
-                        if "PunctType=Dash" not in t.morph:
-                            adj[head] = "positive_adjective"
+                    for t in head.children:
+                        if t.pos_ == "ADJ":
+                            adj[t] = "positive_adjective"
+                        if t.dep_ == "advmod":
                             adj[t] = "positive_adjective"
 
-        if token.pos_ == "ADJ" and (token.dep_ == "npadvmod" or token.dep_ == "advmod"):
+        if token.dep_ == "acomp":
+            for child in token.children:
+                if "PunctType=Dash" in child.morph:
+                    for t in token.children:
+                        if t.pos_ == "ADV" or child.pos_ == "ADJ":
+                            adj[token] = "positive_adjective"
+                            adj[t] = "positive_adjective"
+
+        if token.pos_ == "ADJ" and (token.head.pos_ == "VERB" or token.head.pos_ == "AUX") and token in adj:
             del adj[token]
+
+        if token.pos_ == "ADJ" and (token.dep_ == "npadvmod" or token.dep_ == "advmod") and token in adj:
+            del adj[token]
+
     return adj
+
+
+def adverbs(doc):
+    adv = {}
+
+    for token in doc:
+        if token.tag_ == "RB":
+            adv[token] = "positive_adverb"
+
+        if token.tag_ == "RB":
+            head = token
+            for child in head.children:
+                if "Degree=Cmp" in child.morph and child.tag_ == "RBR":
+                    adv[head] = "comparative_adverb"
+                    adv[child] = "comparative_adverb"
+
+        if "Degree=Cmp" in token.morph and (token not in adv) and token.tag_ == "RBR" and token.head.pos_ == "ADV":
+            adv[token] = "comparative_adverb"
+
+        if token.tag_ == "RB" and token.dep_ == "advmod":
+            head = token
+            for child in head.children:
+                if "Degree=Sup" in child.morph and child.tag_ == "RBS":
+                    adv[head] = "superlative_adverb"
+                    adv[child] = "superlative_adverb"
+
+        if "Degree=Sup" in token.morph and token.tag_ == "JJS" and token.head.pos_ == "ADV":
+            adv[token] = "superlative_adjective"
+
+        if "Degree=Sup" in token.morph and token.pos_ == "ADV":
+            adv[token] = "superlative_adverb"
+
+        if token.pos_ == "ADV":
+            head = token
+            for child in head.children:
+                if "PunctType=Dash" in child.morph:
+                    for t in head.children:
+                        if t.pos_ == "ADV":
+                            adv[t] = "positive_adverb"
+                        if t.dep_ == "advmod":
+                            adv[t] = "positive_adverb"
+
+        if (token.pos_ == "ADJ" and "Degree=Sup" in token.morph) \
+                and (token.dep_ == "npadvmod" or token.dep_ == "advmod"):
+            adv[token] = "superlative_adverb"
+
+    return adv
