@@ -34,6 +34,7 @@ class POSTagger():
         Token.set_extension("verb_tense", default=None, force=True)
         Token.set_extension("modal_verbs", default=None, force=True)
         Token.set_extension("adjectives", default=None, force=True)
+        Token.set_extension("adverbs", default=None, force=True)
         Token.set_extension("is_word", default=False, force=True)
         Token.set_extension("is_function_word", default=False, force=True)
         Token.set_extension("is_content_word", default=False, force=True)
@@ -386,4 +387,10 @@ class POSTagger():
             for token in doc:
                 if t == token:
                     token._.set("adjectives", label)
+
+        adv = grammar.adverbs(doc)
+        for t, label in adv.items():
+            for token in doc:
+                if t == token:
+                    token._.set("adverbs", label)
         return doc
