@@ -38,6 +38,14 @@ class StyloMetrixVector:
         else:
             return self._dicts[item]
 
+    def __delitem__(self, item):
+        if isinstance(item, (list, tuple)):
+            for i in sorted(item, reverse=True):
+                self.__delitem__(i)
+        else:
+            del self._dicts[item]
+
+
     def __copy__(self):
         self.__class__(self.name, self._dicts)
 
